Inline Edit Box Test

# Dijit InlineEditBox Test

## Form Letter with blanks

###

Dear ,

Thank you for your recent order. Please remit for your purchase of deluxe on in ().

Sincerely,

## Form Letter with predefined values, and no auto-save

### Bob Vance Refrigeration

Dear John,

Thank you for your recent order. Please remit $2,000 for your purchase of 3 deluxe refrigerators on 01/05/2007 in Pennsylvania (United States of America).

We sincerely appreciate your business and hope we can do business again.

Sincerely,

Bob Vance

## Inline-block Text (of 400px width)

The following section uses inline block text of 400px. When clicking the editable text it should bring up an editor which is also 400px wide.
(before plain inline)
hello world
(after plain inline)
(before editable inline)
hello world
(after editable inline)

## Pararagraph

(before plain paragraph)

Aliquam vitae enim. Duis scelerisque metus auctor est venenatis imperdiet. Fusce dignissim porta augue. Nulla vestibulum. Integer lorem nunc, ullamcorper a, commodo ac, malesuada sed, dolor. Aenean id mi in massa bibendum suscipit. Integer eros. Nullam suscipit mauris. In pellentesque. Mauris ipsum est, pharetra semper, pharetra in, viverra quis, tellus. Etiam purus. Quisque egestas, tortor ac cursus lacinia, felis leo adipiscing nisi, et rhoncus elit dolor eget eros. Fusce ut quam. Suspendisse eleifend leo vitae ligula. Nulla facilisi. Nulla rutrum, erat vitae lacinia dictum, pede purus imperdiet lacus, ut semper velit ante id metus. Praesent massa dolor, porttitor sed, pulvinar in, consequat ut, leo. Nullam nec est. Aenean id risus blandit tortor pharetra congue. Suspendisse pulvinar.

(before editable paragraph. the editable paragraph has Save/Cancel buttons when open.)

Aliquam vitae enim. Duis scelerisque metus auctor est venenatis imperdiet. Fusce dignissim porta augue. Nulla vestibulum. Integer lorem nunc, ullamcorper a, commodo ac, malesuada sed, dolor. Aenean id mi in massa bibendum suscipit. Integer eros. Nullam suscipit mauris. In pellentesque. Mauris ipsum est, pharetra semper, pharetra in, viverra quis, tellus. Etiam purus. Quisque egestas, tortor ac cursus lacinia, felis leo adipiscing nisi, et rhoncus elit dolor eget eros. Fusce ut quam. Suspendisse eleifend leo vitae ligula. Nulla facilisi. Nulla rutrum, erat vitae lacinia dictum, pede purus imperdiet lacus, ut semper velit ante id metus. Praesent massa dolor, porttitor sed, pulvinar in, consequat ut, leo. Nullam nec est. Aenean id risus blandit tortor pharetra congue. Suspendisse pulvinar.

These buttons will
/
the InlineEditBox above.

## Editor

Aliquam vitae enim. Duis scelerisque metus auctor est venenatis imperdiet. Fusce dignissim porta augue. Nulla vestibulum. Integer lorem nunc, ullamcorper a, commodo ac, malesuada sed, dolor. Aenean id mi in massa bibendum suscipit. Integer eros. Nullam suscipit mauris. In pellentesque. Mauris ipsum est, pharetra semper, pharetra in, viverra quis, tellus. Etiam purus. Quisque egestas, tortor ac cursus lacinia, felis leo adipiscing nisi, et rhoncus elit dolor eget eros. Fusce ut quam. Suspendisse eleifend leo vitae ligula. Nulla facilisi. Nulla rutrum, erat vitae lacinia dictum, pede purus imperdiet lacus, ut semper velit ante id metus. Praesent massa dolor, porttitor sed, pulvinar in, consequat ut, leo. Nullam nec est. Aenean id risus blandit tortor pharetra congue. Suspendisse pulvinar.

Note: since the Editor may return a result containing one or more <p> nodes, don't make the InlineEditBox itself a <p> because that would cause nested <p>s, which is illegal, and messes up IE

## FilteringSelect (no down arrow, and save/cancel buttons):

before Indiana
after

## Programmatically created:

## Complex renderAsHtml="false"

<B>not bold</B>&lt;input&gt;

## Complex renderAsHtml="true"

<B>not bold</B>bold&lt;input&gt;